#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aeson-qq
version:              0.8.3
visibility:           public
id:                   aeson-qq-0.8.3-CmartSkCZrrHGzch7ROwf0
key:                  aeson-qq-0.8.3-CmartSkCZrrHGzch7ROwf0
license:              MIT
maintainer:           Simon Hengel <sol@typeful.net>
author:               Oscar Finnsson
homepage:             https://github.com/sol/aeson-qq#readme
synopsis:             JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.

    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature

    >aesonQQ :: QuasiQuoter

    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>

category:             JSON
abi:                  c4f90c9f315b076687bfe0d889a82a27
exposed:              True
exposed-modules:      Data.Aeson.QQ
hidden-modules:       Data.JSON.QQ Paths_aeson_qq
import-dirs:          /usr/lib/ghc-8.10.2/site-local/aeson-qq-0.8.3
library-dirs:         /usr/lib/ghc-8.10.2/site-local/aeson-qq-0.8.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/aeson-qq-0.8.3
hs-libraries:         HSaeson-qq-0.8.3-CmartSkCZrrHGzch7ROwf0
depends:
    aeson-1.5.5.1-7ZKmq9KLIncxnBfAj9HU2
    attoparsec-0.13.2.4-7uGnKXAWXqp2Qn14d3Hl25 base-4.14.1.0
    base-compat-0.11.2-JggHr2fdYLe83DSFk1MYK3
    haskell-src-meta-0.8.5-9Ff4IOGbOa4EbVYbCvsU0X parsec-3.1.14.0
    scientific-0.3.6.2-Es7urXKqj0FVel3uHj76m template-haskell-2.16.0.0
    text-1.2.3.2 vector-0.12.1.2-IO5RJnkQnAxDAG50LdixTd

haddock-interfaces:   /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html:         /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

